==> mobroute-0.5.0.tar.gz: mobroute-v0.5.0/dbt/types.go <==
// Package dbt (short for database type) contains the types for data
// extracted by the database by the dbquery package. Isolation provides
// more clarity that the types in this dbt package can be used independently
// of dbquery itself. For example the csa package utilizes this dbt package;
// but the tests themsleves for CSA don't touch the db at all.
package dbt

type Connection struct {
	ConnID string `db:"conn_id"`
	TripID string `db:"trip_id"`

	FromST           int    `db:"from_stop_drutctime"`
	FromStopSequence string `db:"from_stop_sequence"`
	FromSSIDU        string `db:"from_stop_sidu"`

	ToSSIDU        string `db:"to_stop_sidu"`
	ToStopSequence string `db:"to_stop_sequence"`
	ToST           int    `db:"to_stop_drutctime"`
}

type StopWalk struct {
	StopSIDU string   `db:"stop_sidu"`
	StopName string   `db:"stop_name"`
	DistKM   *float64 `db:"dist_km"`
}

type ConnectionVerbose struct {
	Source            int     `db:"source" json:"source,omitempty"`
	ConnID            string  `db:"conn_id" json:"conn_id,omitempty"`
	ServiceID         string  `db:"service_id" json:"service_id,omitempty"`
	ServiceDate       string  `db:"service_date" json:"service_date,omitempty"`
	FromStopID        string  `db:"from_stop_id" json:"from_stop_id,omitempty"`
	DirectionID       *int    `db:"direction_id" json:"direction_id,omitempty"`
	FromStopSequence  int     `db:"from_stop_sequence" json:"from_stop_sequence,omitempty"`
	FromStopIDU       string  `db:"from_stop_idu" json:"from_stop_idu,omitempty"`
	FromStopSIDU      string  `db:"from_stop_sidu" json:"from_stop_sidu,omitempty"`
	FromStopLat       float64 `db:"from_stop_lat" json:"from_stop_lat,omitempty"`
	FromStopLon       float64 `db:"from_stop_lon" json:"from_stop_lon,omitempty"`
	FromStopName      string  `db:"from_stop_name" json:"from_stop_name,omitempty"`
	FromStopTime      uint    `db:"from_stop_time" json:"from_stop_time,omitempty"`
	FromStopDRUTCTime int     `db:"from_stop_drutctime" json:"from_stop_drutctime,omitempty"`
	RouteID           string  `db:"route_id" json:"route_id,omitempty"`
	AgencyID          *string `db:"agency_id" json:"agency_id,omitempty"`
	RouteShortName    *string `db:"route_short_name" json:"route_short_name,omitempty"`
	RouteLongName     *string `db:"route_long_name" json:"route_long_name,omitempty"`
	TripID            string  `db:"trip_id" json:"tid,omitempty"`
	ToStopSequence    string  `db:"to_storutctime" json:"to_storutctime,omitempty"`
	ToStopID          string  `db:"to_stop_id" json:"to_stop_id,omitempty"`
	ToStopIDU         string  `db:"to_stop_idu" json:"to_stop_idu,omitempty"`
	ToStopSIDU        string  `db:"to_stop_sidu" json:"to_stop_sidu,omitempty"`
	ToStopLat         float64 `db:"to_stop_lat" json:"to_stop_lat,omitempty"`
	ToStopLon         float64 `db:"to_stop_lon" json:"to_stop_lon,omitempty"`
	ToStopName        string  `db:"to_stop_name" json:"to_stop_name,omitempty"`
	ToStopTime        uint    `db:"to_stop_time" json:"to_stop_time,omitempty"`
	ToStopDRUTCTime   int     `db:"to_stop_drutctime" json:"to_stop_drutctime,omitempty"`
	TripHeadsign      *string `db:"trip_headsign" json:"trip_headsign,omitempty"`
}

type Transfer struct {
	FromSource  int    `db:"from_source"`
	FromSSIDU   string `db:"from_stop_sidu"`
	FromStopIDU string `db:"from_stop_idu"`
	FromStopID  string `db:"from_stop_id"`

	ToSource  int    `db:"to_source"`
	ToSSIDU   string `db:"to_stop_sidu"`
	ToStopIDU string `db:"to_stop_idu"`
	ToStopID  string `db:"to_stop_id"`

	TransferCategory string `db:"transfer_category"`
	TransferSeconds  uint   `db:"transfer_seconds"`
}

==> mobroute-0.8.4.tar.gz: mobroute-v0.8.4/dbt/types.go <==
// Package dbt (short for database type) contains the types for data
// extracted by the database by the dbquery package. Isolation provides
// more clarity that the types in this dbt package can be used independently
// of dbquery itself. For example the csa package utilizes this dbt package;
// but the tests themsleves for CSA don't touch the db at all.
package dbt

type Connection struct {
	ConnID string `db:"conn_id"`
	TripID string `db:"trip_id"`

	FromST           int    `db:"from_stop_drutctime"`
	FromStopSequence string `db:"from_stop_sequence"`
	FromSSIDU        string `db:"from_stop_sidu"`

	ToSSIDU        string `db:"to_stop_sidu"`
	ToStopSequence string `db:"to_stop_sequence"`
	ToST           int    `db:"to_stop_drutctime"`
}

type StopWalk struct {
	StopSIDU string   `db:"stop_sidu" json:"stop_sidu"`
	StopName string   `db:"stop_name" json:"stop_name"`
	StopLat  float64  `db:"stop_lat" json:"stop_lat"`
	StopLon  float64  `db:"stop_lon" json:"stop_lon"`
	DistKM   *float64 `db:"dist_km" json:"dist_km"`
}

type StopTime struct {
	StopSIDU       string  `db:"stop_sidu" json:"stop_sidu"`
	StopDRUTCTime  int     `db:"stop_drutctime" json:"stop_drutctime"`
	RouteShortName *string `db:"route_short_name" json:"route_short_name,omitempty"`
	RouteLongName  *string `db:"route_long_name" json:"route_long_name,omitempty"`
	TripHeadsign   *string `db:"trip_headsign" json:"trip_headsign,omitempty"`
}

type ConnectionVerbose struct {
	FeedID            int     `db:"feed_id" json:"feed_id,omitempty"`
	ConnID            string  `db:"conn_id" json:"conn_id,omitempty"`
	ServiceID         string  `db:"service_id" json:"service_id,omitempty"`
	ServiceDate       string  `db:"service_date" json:"service_date,omitempty"`
	FromStopID        string  `db:"from_stop_id" json:"from_stop_id,omitempty"`
	DirectionID       *int    `db:"direction_id" json:"direction_id,omitempty"`
	FromStopSequence  int     `db:"from_stop_sequence" json:"from_stop_sequence,omitempty"`
	FromStopIDU       string  `db:"from_stop_idu" json:"from_stop_idu,omitempty"`
	FromStopSIDU      string  `db:"from_stop_sidu" json:"from_stop_sidu,omitempty"`
	FromStopLat       float64 `db:"from_stop_lat" json:"from_stop_lat,omitempty"`
	FromStopLon       float64 `db:"from_stop_lon" json:"from_stop_lon,omitempty"`
	FromStopName      string  `db:"from_stop_name" json:"from_stop_name,omitempty"`
	FromStopTime      uint    `db:"from_stop_time" json:"from_stop_time,omitempty"`
	FromStopDRUTCTime int     `db:"from_stop_drutctime" json:"from_stop_drutctime,omitempty"`
	RouteID           string  `db:"route_id" json:"route_id,omitempty"`
	AgencyID          *string `db:"agency_id" json:"agency_id,omitempty"`
	RouteShortName    *string `db:"route_short_name" json:"route_short_name,omitempty"`
	RouteLongName     *string `db:"route_long_name" json:"route_long_name,omitempty"`
	TripID            string  `db:"trip_id" json:"tid,omitempty"`
	ToStopSequence    string  `db:"to_stop_sequence" json:"to_stop_sequence,omitempty"`
	ToStopID          string  `db:"to_stop_id" json:"to_stop_id,omitempty"`
	ToStopIDU         string  `db:"to_stop_idu" json:"to_stop_idu,omitempty"`
	ToStopSIDU        string  `db:"to_stop_sidu" json:"to_stop_sidu,omitempty"`
	ToStopLat         float64 `db:"to_stop_lat" json:"to_stop_lat,omitempty"`
	ToStopLon         float64 `db:"to_stop_lon" json:"to_stop_lon,omitempty"`
	ToStopName        string  `db:"to_stop_name" json:"to_stop_name,omitempty"`
	ToStopTime        uint    `db:"to_stop_time" json:"to_stop_time,omitempty"`
	ToStopDRUTCTime   int     `db:"to_stop_drutctime" json:"to_stop_drutctime,omitempty"`
	TripHeadsign      *string `db:"trip_headsign" json:"trip_headsign,omitempty"`
}

type Transfer struct {
	FromFeedID  int    `db:"from_feed_id"`
	FromSSIDU   string `db:"from_stop_sidu"`
	FromStopIDU string `db:"from_stop_idu"`
	FromStopID  string `db:"from_stop_id"`

	ToFeedID  int    `db:"to_feed_id"`
	ToSSIDU   string `db:"to_stop_sidu"`
	ToStopIDU string `db:"to_stop_idu"`
	ToStopID  string `db:"to_stop_id"`

	TransferCategory string `db:"transfer_category"`
	TransferSeconds  uint   `db:"transfer_seconds"`
}
